aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2011-04-01 07:28:07 +0200
committerSven Gothel <[email protected]>2011-04-01 07:28:07 +0200
commit4dd315dec00eacfb629c4442dc42a8538d7527d3 (patch)
tree0554dcfae20684472855311486d53a1ba553516b
parent16ba4d6f3ede9a9e35a9947d1b0cf6dba56659ac (diff)
integrated typecast into jogamp. tree
-rw-r--r--.externalToolBuilders/jogl builder.launch6
-rw-r--r--make/build-jogl.xml9
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/TypecastFont.java16
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/TypecastFontConstructor.java2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/TypecastHMetrics.java5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/TypecastRenderer.java8
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/Disassembler.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/Disassembler.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/Fixed.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/Fixed.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/Mnemonic.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/Mnemonic.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/OTFont.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/OTFont.java)37
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/OTFontCollection.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/OTFontCollection.java)17
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/OTGlyph.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/OTGlyph.java)13
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/Point.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/Point.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceData.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceData.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceFile.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceFile.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceHeader.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceHeader.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceMap.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceMap.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceReference.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceReference.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceType.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceType.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/BaseTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/BaseTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffStandardStrings.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CffStandardStrings.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CffTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Charstring.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Charstring.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CharstringType2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CharstringType2.java)4
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDef.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ClassDef.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat1.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat1.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat2.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat0.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat0.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat2.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat4.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat4.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat6.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat6.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormatUnknown.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormatUnknown.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapIndexEntry.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapIndexEntry.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CmapTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Coverage.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Coverage.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat1.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat1.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat2.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/CvtTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/CvtTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Device.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Device.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/DirectoryEntry.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/DirectoryEntry.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigEntry.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/DsigEntry.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/DsigTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Feature.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Feature.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureList.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/FeatureList.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureRecord.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/FeatureRecord.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureTags.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/FeatureTags.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/FpgmTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/FpgmTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspRange.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GaspRange.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GaspTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeComp.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeComp.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeDescript.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeDescript.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfDescript.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyfDescript.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfSimpleDescript.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyfSimpleDescript.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyfTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyphDescription.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GlyphDescription.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GposTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GposTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/GsubTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/GsubTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/HdmxTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/HdmxTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/HeadTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/HeadTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/HheaTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/HheaTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/HmtxTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/HmtxTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ID.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ID.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat0.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat0.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat2.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/KernTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/KerningPair.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/KerningPair.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSys.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LangSys.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSysRecord.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LangSysRecord.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Ligature.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Ligature.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSet.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSet.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubst.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubst.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubstFormat1.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubstFormat1.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LocaTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LocaTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Lookup.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Lookup.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupList.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LookupList.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtableFactory.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtableFactory.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/LtshTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/LtshTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/MaxpTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/MaxpTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameRecord.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/NameRecord.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/NameTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Os2Table.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Os2Table.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Panose.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Panose.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/PcltTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/PcltTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/PostTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/PostTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/PrepTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/PrepTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Program.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Program.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/RangeRecord.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/RangeRecord.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Script.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Script.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptList.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ScriptList.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptRecord.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ScriptRecord.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptTags.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/ScriptTags.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/SignatureBlock.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/SignatureBlock.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubst.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubst.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat1.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat1.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat2.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat2.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/TTCHeader.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/TTCHeader.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/Table.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/Table.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableDirectory.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/TableDirectory.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableException.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/TableException.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableFactory.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/TableFactory.java)7
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/VdmxTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/VdmxTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/VheaTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/VheaTable.java)5
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/ot/table/VmtxTable.java (renamed from src/jogl/classes/net/java/dev/typecast/ot/table/VmtxTable.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/t2/T2Interpreter.java (renamed from src/jogl/classes/net/java/dev/typecast/t2/T2Interpreter.java)13
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/t2/T2Mnemonic.java (renamed from src/jogl/classes/net/java/dev/typecast/t2/T2Mnemonic.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/tt/engine/GraphicsState.java (renamed from src/jogl/classes/net/java/dev/typecast/tt/engine/GraphicsState.java)2
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Interpreter.java (renamed from src/jogl/classes/net/java/dev/typecast/tt/engine/Interpreter.java)6
-rw-r--r--src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Parser.java (renamed from src/jogl/classes/net/java/dev/typecast/tt/engine/Parser.java)4
-rw-r--r--src/jogl/classes/jogamp/graph/geom/plane/AffineTransform.java2
-rw-r--r--src/jogl/classes/jogamp/opengl/util/HashCode.java (renamed from src/jogl/classes/org/apache/harmony/misc/HashCode.java)2
113 files changed, 200 insertions, 172 deletions
diff --git a/.externalToolBuilders/jogl builder.launch b/.externalToolBuilders/jogl builder.launch
index eab22e8ed..7c9fe7a24 100644
--- a/.externalToolBuilders/jogl builder.launch
+++ b/.externalToolBuilders/jogl builder.launch
@@ -7,6 +7,12 @@
<booleanAttribute key="org.eclipse.ant.ui.ATTR_TARGETS_UPDATED" value="true"/>
<booleanAttribute key="org.eclipse.ant.ui.DEFAULT_VM_INSTALL" value="false"/>
<stringAttribute key="org.eclipse.debug.core.ATTR_REFRESH_SCOPE" value="${project}"/>
+<listAttribute key="org.eclipse.debug.core.MAPPED_RESOURCE_PATHS">
+<listEntry value="/jogl"/>
+</listAttribute>
+<listAttribute key="org.eclipse.debug.core.MAPPED_RESOURCE_TYPES">
+<listEntry value="4"/>
+</listAttribute>
<booleanAttribute key="org.eclipse.debug.ui.ATTR_LAUNCH_IN_BACKGROUND" value="false"/>
<stringAttribute key="org.eclipse.jdt.launching.CLASSPATH_PROVIDER" value="org.eclipse.ant.ui.AntClasspathProvider"/>
<booleanAttribute key="org.eclipse.jdt.launching.DEFAULT_CLASSPATH" value="true"/>
diff --git a/make/build-jogl.xml b/make/build-jogl.xml
index c14f66794..aef4b2f47 100644
--- a/make/build-jogl.xml
+++ b/make/build-jogl.xml
@@ -141,6 +141,9 @@
<property name="java.part.util.glsl"
value="com/jogamp/opengl/util/glsl/* com/jogamp/opengl/util/glsl/fixedfunc/*"/>
+ <property name="java.part.util.graph"
+ value="com/jogamp/graph/** jogamp/graph/**"/>
+
<property name="java.part.util.fixedfuncemu"
value="jogamp/opengl/util/glsl/fixedfunc/**"/>
@@ -1466,7 +1469,9 @@
<include name="javax/media/opengl/**" />
<include name="com/jogamp/gluegen/runtime/**" />
<include name="com/jogamp/opengl/**" />
+ <include name="com/jogamp/graph/**" />
<include name="jogamp/opengl/**" />
+ <include name="jogamp/graph/**" />
</fileset>
<fileset dir="${src.java}"
includes="${java.part.util.fixedfuncemu.shadercode}"/>
@@ -1480,7 +1485,9 @@
<include name="javax/media/opengl/**" />
<include name="com/jogamp/gluegen/runtime/**" />
<include name="com/jogamp/opengl/**" />
+ <include name="com/jogamp/graph/**" />
<include name="jogamp/opengl/**" />
+ <include name="jogamp/graph/**" />
</fileset>
<fileset dir="${src.java}"
includes="${java.part.util.fixedfuncemu.shadercode}"/>
@@ -1531,7 +1538,7 @@
</jar>
<jar manifest="${build.jogl}/tempversion" destfile="${jogl.util.jar}" filesonly="true">
<fileset dir="${classes}"
- includes="${java.part.util} ${java.part.util.glsl}"
+ includes="${java.part.util} ${java.part.util.glsl} ${java.part.util.graph}"
excludes="${java.part.util.awt} ${java.part.util.gldesktop} ${java.part.util.fixedfuncemu}"/>
</jar>
<jar manifest="${build.jogl}/tempversion" destfile="${jogl.util.fixedfuncemu.jar}" filesonly="true">
diff --git a/src/jogl/classes/jogamp/graph/font/typecast/TypecastFont.java b/src/jogl/classes/jogamp/graph/font/typecast/TypecastFont.java
index 0d018a314..35c62a3d9 100644
--- a/src/jogl/classes/jogamp/graph/font/typecast/TypecastFont.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/TypecastFont.java
@@ -28,15 +28,15 @@
package jogamp.graph.font.typecast;
import jogamp.graph.font.FontInt;
+import jogamp.graph.font.typecast.ot.OTFont;
+import jogamp.graph.font.typecast.ot.OTFontCollection;
+import jogamp.graph.font.typecast.ot.table.CmapFormat;
+import jogamp.graph.font.typecast.ot.table.CmapIndexEntry;
+import jogamp.graph.font.typecast.ot.table.CmapTable;
+import jogamp.graph.font.typecast.ot.table.HdmxTable;
+import jogamp.graph.font.typecast.ot.table.ID;
import jogamp.graph.geom.plane.AffineTransform;
import jogamp.graph.geom.plane.Path2D;
-import net.java.dev.typecast.ot.OTFont;
-import net.java.dev.typecast.ot.OTFontCollection;
-import net.java.dev.typecast.ot.table.CmapFormat;
-import net.java.dev.typecast.ot.table.CmapIndexEntry;
-import net.java.dev.typecast.ot.table.CmapTable;
-import net.java.dev.typecast.ot.table.HdmxTable;
-import net.java.dev.typecast.ot.table.ID;
import com.jogamp.common.util.IntObjectHashMap;
import com.jogamp.graph.geom.AABBox;
@@ -164,7 +164,7 @@ class TypecastFont implements FontInt {
}
}
- net.java.dev.typecast.ot.OTGlyph glyph = font.getGlyph(code);
+ jogamp.graph.font.typecast.ot.OTGlyph glyph = font.getGlyph(code);
if(null == glyph) {
glyph = font.getGlyph(Glyph.ID_UNKNOWN);
}
diff --git a/src/jogl/classes/jogamp/graph/font/typecast/TypecastFontConstructor.java b/src/jogl/classes/jogamp/graph/font/typecast/TypecastFontConstructor.java
index 5fb9d32f7..f3bde47d1 100644
--- a/src/jogl/classes/jogamp/graph/font/typecast/TypecastFontConstructor.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/TypecastFontConstructor.java
@@ -31,8 +31,8 @@ import java.io.File;
import java.io.IOException;
import jogamp.graph.font.FontConstructor;
+import jogamp.graph.font.typecast.ot.OTFontCollection;
-import net.java.dev.typecast.ot.OTFontCollection;
import com.jogamp.graph.font.Font;
diff --git a/src/jogl/classes/jogamp/graph/font/typecast/TypecastHMetrics.java b/src/jogl/classes/jogamp/graph/font/typecast/TypecastHMetrics.java
index cd8595498..a69948006 100644
--- a/src/jogl/classes/jogamp/graph/font/typecast/TypecastHMetrics.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/TypecastHMetrics.java
@@ -27,8 +27,9 @@
*/
package jogamp.graph.font.typecast;
-import net.java.dev.typecast.ot.table.HeadTable;
-import net.java.dev.typecast.ot.table.HheaTable;
+import jogamp.graph.font.typecast.ot.table.HeadTable;
+import jogamp.graph.font.typecast.ot.table.HheaTable;
+
import com.jogamp.graph.font.Font.Metrics;
import com.jogamp.graph.geom.AABBox;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/Disassembler.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/Disassembler.java
index 73e75cc39..0ac5f0bda 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/Disassembler.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/Disassembler.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
/**
* @author <a href="mailto:[email protected]">David Schweinsberg</a>
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/Fixed.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/Fixed.java
index 6f83e922c..ece0aae4b 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/Fixed.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/Fixed.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
/**
* Functions for working with signed 16.16 fixed values
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/Mnemonic.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/Mnemonic.java
index 5655c1e86..5afb939ab 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/Mnemonic.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/Mnemonic.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
/**
* The Mnemonic representations of the TrueType instruction set.
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/OTFont.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTFont.java
index e58fc3794..3740dac6f 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/OTFont.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTFont.java
@@ -48,28 +48,29 @@
*/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
import java.io.DataInputStream;
import java.io.IOException;
-import net.java.dev.typecast.ot.table.DirectoryEntry;
-import net.java.dev.typecast.ot.table.GlyfDescript;
-import net.java.dev.typecast.ot.table.HdmxTable;
-import net.java.dev.typecast.ot.table.TableDirectory;
-import net.java.dev.typecast.ot.table.Table;
-import net.java.dev.typecast.ot.table.Os2Table;
-import net.java.dev.typecast.ot.table.CmapTable;
-import net.java.dev.typecast.ot.table.GlyfTable;
-import net.java.dev.typecast.ot.table.HeadTable;
-import net.java.dev.typecast.ot.table.HheaTable;
-import net.java.dev.typecast.ot.table.HmtxTable;
-import net.java.dev.typecast.ot.table.LocaTable;
-import net.java.dev.typecast.ot.table.MaxpTable;
-import net.java.dev.typecast.ot.table.NameTable;
-import net.java.dev.typecast.ot.table.PostTable;
-import net.java.dev.typecast.ot.table.VheaTable;
-import net.java.dev.typecast.ot.table.TableFactory;
+import jogamp.graph.font.typecast.ot.table.CmapTable;
+import jogamp.graph.font.typecast.ot.table.DirectoryEntry;
+import jogamp.graph.font.typecast.ot.table.GlyfDescript;
+import jogamp.graph.font.typecast.ot.table.GlyfTable;
+import jogamp.graph.font.typecast.ot.table.HdmxTable;
+import jogamp.graph.font.typecast.ot.table.HeadTable;
+import jogamp.graph.font.typecast.ot.table.HheaTable;
+import jogamp.graph.font.typecast.ot.table.HmtxTable;
+import jogamp.graph.font.typecast.ot.table.LocaTable;
+import jogamp.graph.font.typecast.ot.table.MaxpTable;
+import jogamp.graph.font.typecast.ot.table.NameTable;
+import jogamp.graph.font.typecast.ot.table.Os2Table;
+import jogamp.graph.font.typecast.ot.table.PostTable;
+import jogamp.graph.font.typecast.ot.table.Table;
+import jogamp.graph.font.typecast.ot.table.TableDirectory;
+import jogamp.graph.font.typecast.ot.table.TableFactory;
+import jogamp.graph.font.typecast.ot.table.VheaTable;
+
/**
* The TrueType font.
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/OTFontCollection.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTFontCollection.java
index 6f8754f59..53a8890bc 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/OTFontCollection.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTFontCollection.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
import java.io.File;
import java.io.BufferedInputStream;
@@ -28,13 +28,14 @@ import java.io.IOException;
import java.util.ArrayList;
-import net.java.dev.typecast.ot.mac.ResourceHeader;
-import net.java.dev.typecast.ot.mac.ResourceMap;
-import net.java.dev.typecast.ot.mac.ResourceReference;
-import net.java.dev.typecast.ot.mac.ResourceType;
-import net.java.dev.typecast.ot.table.DirectoryEntry;
-import net.java.dev.typecast.ot.table.Table;
-import net.java.dev.typecast.ot.table.TTCHeader;
+import jogamp.graph.font.typecast.ot.mac.ResourceHeader;
+import jogamp.graph.font.typecast.ot.mac.ResourceMap;
+import jogamp.graph.font.typecast.ot.mac.ResourceReference;
+import jogamp.graph.font.typecast.ot.mac.ResourceType;
+import jogamp.graph.font.typecast.ot.table.DirectoryEntry;
+import jogamp.graph.font.typecast.ot.table.TTCHeader;
+import jogamp.graph.font.typecast.ot.table.Table;
+
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/OTGlyph.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTGlyph.java
index 958dd2280..4b6242d56 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/OTGlyph.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/OTGlyph.java
@@ -48,16 +48,17 @@
*/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
+
+import jogamp.graph.font.typecast.ot.table.Charstring;
+import jogamp.graph.font.typecast.ot.table.CharstringType2;
+import jogamp.graph.font.typecast.ot.table.GlyfDescript;
+import jogamp.graph.font.typecast.ot.table.GlyphDescription;
+import jogamp.graph.font.typecast.t2.T2Interpreter;
import com.jogamp.graph.geom.AABBox;
-import net.java.dev.typecast.ot.table.GlyphDescription;
-import net.java.dev.typecast.ot.table.GlyfDescript;
-import net.java.dev.typecast.ot.table.Charstring;
-import net.java.dev.typecast.ot.table.CharstringType2;
-import net.java.dev.typecast.t2.T2Interpreter;
/**
* An individual glyph within a font.
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/Point.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/Point.java
index fae13b098..f1a090d68 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/Point.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/Point.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot;
+package jogamp.graph.font.typecast.ot;
/**
* @version $Id: Point.java,v 1.1.1.1 2004-12-05 23:14:31 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceData.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceData.java
index a1c12ffc0..433ff6051 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceData.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceData.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceFile.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceFile.java
index e9499d9e8..2ada22c82 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceFile.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceFile.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.IOException;
import java.io.RandomAccessFile;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceHeader.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceHeader.java
index bdfe15a72..8f5224632 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceHeader.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceHeader.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceMap.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceMap.java
index ee98fd8eb..96ba06087 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceMap.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceMap.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceReference.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceReference.java
index f7f6e0fdf..fd7ec46b2 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceReference.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceReference.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceType.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceType.java
index 2c21e7a27..969aa9643 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/mac/ResourceType.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/mac/ResourceType.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.mac;
+package jogamp.graph.font.typecast.ot.mac;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/BaseTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/BaseTable.java
index f92de718f..659b0cd38 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/BaseTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/BaseTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.ByteArrayInputStream;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CffStandardStrings.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffStandardStrings.java
index 987ea886c..bf6bd6a67 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CffStandardStrings.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffStandardStrings.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* Compact Font Format Standard Strings. As per Appendix A of the Adobe
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CffTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffTable.java
index 2bd0cec63..0c54c27d6 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CffTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CffTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.ByteArrayInputStream;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Charstring.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Charstring.java
index 2439d6bc5..d411d1e00 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Charstring.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Charstring.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* CFF Charstring
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CharstringType2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CharstringType2.java
index e47825cf3..bed0ba4b0 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CharstringType2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CharstringType2.java
@@ -18,9 +18,9 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
-import net.java.dev.typecast.ot.table.CffTable;
+import jogamp.graph.font.typecast.ot.table.CffTable;
/**
* CFF Type 2 Charstring
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDef.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDef.java
index 9fa45c3c6..4c2f3decb 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDef.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDef.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.RandomAccessFile;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat1.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat1.java
index 07b85ddf9..0c99ad66a 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat1.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat1.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.RandomAccessFile;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat2.java
index f8b883c41..5b7c4d655 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ClassDefFormat2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ClassDefFormat2.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.RandomAccessFile;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat.java
index be88af1e6..45e21df07 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat0.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat0.java
index 80f42b227..e374f82d2 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat0.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat0.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat2.java
index 4eeaf420a..319d8c0d0 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat2.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat4.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat4.java
index 3748a8f84..d2baf2b22 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat4.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat4.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat6.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat6.java
index f9b398aab..a58531d11 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormat6.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormat6.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormatUnknown.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormatUnknown.java
index 01ca600f1..83366b593 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapFormatUnknown.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapFormatUnknown.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapIndexEntry.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapIndexEntry.java
index c82e270fb..df18a7fb0 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapIndexEntry.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapIndexEntry.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapTable.java
index de69cc1f0..b93de50d3 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CmapTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CmapTable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Coverage.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Coverage.java
index 3c6cf0409..e85fadb5e 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Coverage.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Coverage.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat1.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat1.java
index a81eb0f1e..712da54df 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat1.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat1.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat2.java
index a30489647..7196ed595 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CoverageFormat2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CoverageFormat2.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/CvtTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CvtTable.java
index 44dc0af41..189d0805c 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/CvtTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/CvtTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Device.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Device.java
index 75c302acd..6b4af6908 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Device.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Device.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.RandomAccessFile;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/DirectoryEntry.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DirectoryEntry.java
index c0f2f9bc1..d2f93ded1 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/DirectoryEntry.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DirectoryEntry.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/DsigEntry.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigEntry.java
index 6ce41ec48..4b41f451d 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/DsigEntry.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigEntry.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/DsigTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigTable.java
index 8d63800d4..34f321e28 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/DsigTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/DsigTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Feature.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Feature.java
index 34adf4662..ee27896a4 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Feature.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Feature.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureList.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureList.java
index 8f17c461f..3cfb54a38 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureList.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureList.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureRecord.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureRecord.java
index 7c2788892..49a8ef906 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureRecord.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureRecord.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureTags.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureTags.java
index 8d573d0c6..a5584a207 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/FeatureTags.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FeatureTags.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* Definition of Feature tags
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/FpgmTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FpgmTable.java
index 37a2ae045..9a6000156 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/FpgmTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/FpgmTable.java
@@ -6,11 +6,12 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Disassembler;
+
+import jogamp.graph.font.typecast.ot.Disassembler;
/**
* @version $Id: FpgmTable.java,v 1.1.1.1 2004-12-05 23:14:38 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GaspRange.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspRange.java
index 9f343e942..fe7e9f665 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GaspRange.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspRange.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GaspTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspTable.java
index 50a1bcd93..611ee16ff 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GaspTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GaspTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeComp.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeComp.java
index 0a3f91a2a..e5c86873e 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeComp.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeComp.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeDescript.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeDescript.java
index 97c0b0f79..4cf254198 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfCompositeDescript.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfCompositeDescript.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfDescript.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfDescript.java
index 49ae5b494..3fc113f2e 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfDescript.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfDescript.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfSimpleDescript.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfSimpleDescript.java
index e2c3a2c84..c5c76712c 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfSimpleDescript.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfSimpleDescript.java
@@ -48,11 +48,12 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Disassembler;
+
+import jogamp.graph.font.typecast.ot.Disassembler;
/**
* @version $Id: GlyfSimpleDescript.java,v 1.3 2007-01-24 09:47:47 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfTable.java
index 03f519db2..22fdd8886 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyfTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyfTable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.ByteArrayInputStream;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyphDescription.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyphDescription.java
index b23f31364..106e17917 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GlyphDescription.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GlyphDescription.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* Specifies access to glyph description classes, simple and composite.
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GposTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GposTable.java
index 3efeeaa03..91a62362a 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GposTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GposTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/GsubTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GsubTable.java
index d7f9c355f..c002de374 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/GsubTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/GsubTable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.ByteArrayInputStream;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/HdmxTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HdmxTable.java
index 68a03c590..64ac9d659 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/HdmxTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HdmxTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/HeadTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HeadTable.java
index c99ae768d..122a50faa 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/HeadTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HeadTable.java
@@ -48,12 +48,13 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+import jogamp.graph.font.typecast.ot.Fixed;
+
/**
* @version $Id: HeadTable.java,v 1.2 2004-12-21 10:23:20 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/HheaTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HheaTable.java
index 4b49f41be..6cafab4e5 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/HheaTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HheaTable.java
@@ -6,11 +6,12 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+
+import jogamp.graph.font.typecast.ot.Fixed;
/**
* @version $Id: HheaTable.java,v 1.2 2010-08-10 11:44:02 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/HmtxTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HmtxTable.java
index 7b4cbae40..c2e892e34 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/HmtxTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/HmtxTable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ID.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ID.java
index 5dc79d766..9fd66e728 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ID.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ID.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtable.java
index f55fa04fb..7a4cccba2 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat0.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat0.java
index e3b1c9cf9..b55bef6d5 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat0.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat0.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat2.java
index 5ff37c291..60d584ca6 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/KernSubtableFormat2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernSubtableFormat2.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/KernTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernTable.java
index 81c4a998f..70aee70d2 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/KernTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KernTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/KerningPair.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KerningPair.java
index de614235f..ce7cebc97 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/KerningPair.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/KerningPair.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LangSys.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSys.java
index 9963bf6af..6759208f5 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LangSys.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSys.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LangSysRecord.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSysRecord.java
index a69c12a44..5777bd642 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LangSysRecord.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LangSysRecord.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Ligature.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Ligature.java
index 36969ba7a..d3e2ad5cd 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Ligature.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Ligature.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSet.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSet.java
index fe6db0445..e261f3a88 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSet.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSet.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubst.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubst.java
index 73a8b9d36..c0570cde9 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubst.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubst.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubstFormat1.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubstFormat1.java
index b19b07111..a0f42662c 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LigatureSubstFormat1.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LigatureSubstFormat1.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LocaTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LocaTable.java
index 5f62940df..8187708a3 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LocaTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LocaTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Lookup.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Lookup.java
index d6e46cd91..2899c24d9 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Lookup.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Lookup.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupList.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupList.java
index 9ac76aba5..a3b71b639 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupList.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupList.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtable.java
index 4d8dbb180..1d19038f3 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtableFactory.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtableFactory.java
index 2081e2ea6..cb4d28d2c 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LookupSubtableFactory.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LookupSubtableFactory.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/LtshTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LtshTable.java
index 12dca01f4..2cba7baf2 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/LtshTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/LtshTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/MaxpTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/MaxpTable.java
index 571d3ebfd..16b9f827d 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/MaxpTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/MaxpTable.java
@@ -6,11 +6,12 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+
+import jogamp.graph.font.typecast.ot.Fixed;
/**
* @version $Id: MaxpTable.java,v 1.1.1.1 2004-12-05 23:14:52 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/NameRecord.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameRecord.java
index cdba03ef9..04168ff77 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/NameRecord.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameRecord.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/NameTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameTable.java
index 05f823427..26cd067db 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/NameTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/NameTable.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.DataInputStream;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Os2Table.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Os2Table.java
index 9ec599724..f33dd2734 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Os2Table.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Os2Table.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Panose.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Panose.java
index fe0a357d2..84e67078b 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Panose.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Panose.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* @version $Id: Panose.java,v 1.1.1.1 2004-12-05 23:14:54 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/PcltTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PcltTable.java
index 457aec2e1..792b8a832 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/PcltTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PcltTable.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/PostTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PostTable.java
index 4a1b0650b..ed82f2654 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/PostTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PostTable.java
@@ -6,11 +6,12 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+
+import jogamp.graph.font.typecast.ot.Fixed;
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/PrepTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PrepTable.java
index 938b9b840..aac10c539 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/PrepTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/PrepTable.java
@@ -6,11 +6,12 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Disassembler;
+
+import jogamp.graph.font.typecast.ot.Disassembler;
/**
* @version $Id: PrepTable.java,v 1.1.1.1 2004-12-05 23:14:57 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Program.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Program.java
index d4dd094e2..28c148c2b 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Program.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Program.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/RangeRecord.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/RangeRecord.java
index 3bcb9ccb5..72d703bb4 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/RangeRecord.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/RangeRecord.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Script.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Script.java
index e3022c116..eb534b5dd 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Script.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Script.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptList.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptList.java
index bd82a052f..4af62b0ee 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptList.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptList.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptRecord.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptRecord.java
index aea0bf0df..34a43d254 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptRecord.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptRecord.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptTags.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptTags.java
index eeb4f8e25..a5e196e83 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/ScriptTags.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/ScriptTags.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* Definition of Script tags
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/SignatureBlock.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SignatureBlock.java
index 2e4acf525..156d3fde6 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/SignatureBlock.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SignatureBlock.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.IOException;
import java.io.DataInput;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubst.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubst.java
index 91c985883..8c56a740f 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubst.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubst.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat1.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat1.java
index 538c57f6d..99b85f35c 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat1.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat1.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat2.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat2.java
index 74c68f71f..cd3b6d147 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/SingleSubstFormat2.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/SingleSubstFormat2.java
@@ -48,7 +48,7 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/TTCHeader.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TTCHeader.java
index 2f38d33f4..b801517f8 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/TTCHeader.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TTCHeader.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/Table.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Table.java
index ddbdc49e2..87bb0de7a 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/Table.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/Table.java
@@ -6,7 +6,7 @@
* the LICENSE file. *
*****************************************************************************/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
* @version $Id: Table.java,v 1.1.1.1 2004-12-05 23:14:59 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/TableDirectory.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableDirectory.java
index 2eff53dd9..cf9f1bda4 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/TableDirectory.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableDirectory.java
@@ -48,11 +48,12 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+
+import jogamp.graph.font.typecast.ot.Fixed;
/**
* @version $Id: TableDirectory.java,v 1.2 2004-12-09 23:46:21 davidsch Exp $
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/TableException.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableException.java
index 02bc49eb5..7749ea856 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/TableException.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableException.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/TableFactory.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableFactory.java
index 28a7a4a97..998ce08e3 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/TableFactory.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/TableFactory.java
@@ -48,12 +48,13 @@
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInputStream;
import java.io.IOException;
-import net.java.dev.typecast.ot.OTFont;
-import net.java.dev.typecast.ot.OTFontCollection;
+
+import jogamp.graph.font.typecast.ot.OTFont;
+import jogamp.graph.font.typecast.ot.OTFontCollection;
/**
*
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/VdmxTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VdmxTable.java
index 907133b6d..641f3eff8 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/VdmxTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VdmxTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/VheaTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VheaTable.java
index 3863080cf..0fc8bea26 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/VheaTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VheaTable.java
@@ -18,11 +18,12 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
-import net.java.dev.typecast.ot.Fixed;
+
+import jogamp.graph.font.typecast.ot.Fixed;
/**
* Vertical Header Table
diff --git a/src/jogl/classes/net/java/dev/typecast/ot/table/VmtxTable.java b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VmtxTable.java
index b2d9a3c3e..dcd1cd7c1 100644
--- a/src/jogl/classes/net/java/dev/typecast/ot/table/VmtxTable.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/ot/table/VmtxTable.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.ot.table;
+package jogamp.graph.font.typecast.ot.table;
import java.io.DataInput;
import java.io.IOException;
diff --git a/src/jogl/classes/net/java/dev/typecast/t2/T2Interpreter.java b/src/jogl/classes/jogamp/graph/font/typecast/t2/T2Interpreter.java
index 6ae59cf8d..a05bd3ba2 100644
--- a/src/jogl/classes/net/java/dev/typecast/t2/T2Interpreter.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/t2/T2Interpreter.java
@@ -18,13 +18,14 @@
* limitations under the License.
*/
-package net.java.dev.typecast.t2;
+package jogamp.graph.font.typecast.t2;
import java.util.ArrayList;
-import net.java.dev.typecast.ot.Point;
+import jogamp.graph.font.typecast.ot.Point;
+import jogamp.graph.font.typecast.ot.table.CharstringType2;
+
-import net.java.dev.typecast.ot.table.CharstringType2;
/**
* Type 2 Charstring Interpreter. Operator descriptions are quoted from
@@ -477,7 +478,7 @@ public class T2Interpreter {
}
/**
- * Causes two B�zier curves, as described by the arguments (as
+ * Causes two B�zier curves, as described by the arguments (as
* shown in Figure 2 below), to be rendered as a straight line when
* the flex depth is less than fd /100 device pixels, and as curved lines
* when the flex depth is greater than or equal to fd/100 device
@@ -523,7 +524,7 @@ public class T2Interpreter {
/**
* Finishes a charstring outline definition, and must be the
- * last operator in a character�s outline.
+ * last operator in a character�s outline.
*/
private void _endchar() {
endContour();
@@ -667,7 +668,7 @@ public class T2Interpreter {
}
/**
- * Performs a circular shift of the elements num(N�1) ... num0 on
+ * Performs a circular shift of the elements num(N�1) ... num0 on
* the argument stack by the amount J. Positive J indicates upward
* motion of the stack; negative J indicates downward motion.
* The value N must be a non-negative integer, otherwise the
diff --git a/src/jogl/classes/net/java/dev/typecast/t2/T2Mnemonic.java b/src/jogl/classes/jogamp/graph/font/typecast/t2/T2Mnemonic.java
index 810aea159..6e7589cb4 100644
--- a/src/jogl/classes/net/java/dev/typecast/t2/T2Mnemonic.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/t2/T2Mnemonic.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.t2;
+package jogamp.graph.font.typecast.t2;
/**
* The Mnemonic representations of the Type 2 charstring instruction set.
diff --git a/src/jogl/classes/net/java/dev/typecast/tt/engine/GraphicsState.java b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/GraphicsState.java
index 1c36bd3de..b8605ac69 100644
--- a/src/jogl/classes/net/java/dev/typecast/tt/engine/GraphicsState.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/GraphicsState.java
@@ -18,7 +18,7 @@
* limitations under the License.
*/
-package net.java.dev.typecast.tt.engine;
+package jogamp.graph.font.typecast.tt.engine;
/**
* Maintains the graphics state whilst interpreting hinting instructions.
diff --git a/src/jogl/classes/net/java/dev/typecast/tt/engine/Interpreter.java b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Interpreter.java
index 6f436d764..252c6acc4 100644
--- a/src/jogl/classes/net/java/dev/typecast/tt/engine/Interpreter.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Interpreter.java
@@ -18,10 +18,10 @@
* limitations under the License.
*/
-package net.java.dev.typecast.tt.engine;
+package jogamp.graph.font.typecast.tt.engine;
-import net.java.dev.typecast.ot.Mnemonic;
-import net.java.dev.typecast.ot.Point;
+import jogamp.graph.font.typecast.ot.Mnemonic;
+import jogamp.graph.font.typecast.ot.Point;
/**
* The interpreter shall remain ignorant of the table structure - the table
diff --git a/src/jogl/classes/net/java/dev/typecast/tt/engine/Parser.java b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Parser.java
index bfae53197..71260b8f3 100644
--- a/src/jogl/classes/net/java/dev/typecast/tt/engine/Parser.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/tt/engine/Parser.java
@@ -18,9 +18,9 @@
* limitations under the License.
*/
-package net.java.dev.typecast.tt.engine;
+package jogamp.graph.font.typecast.tt.engine;
-import net.java.dev.typecast.ot.Mnemonic;
+import jogamp.graph.font.typecast.ot.Mnemonic;
/**
* @author <a href="mailto:[email protected]">David Schweinsberg</a>
diff --git a/src/jogl/classes/jogamp/graph/geom/plane/AffineTransform.java b/src/jogl/classes/jogamp/graph/geom/plane/AffineTransform.java
index 2ba9f8d06..512d81fcf 100644
--- a/src/jogl/classes/jogamp/graph/geom/plane/AffineTransform.java
+++ b/src/jogl/classes/jogamp/graph/geom/plane/AffineTransform.java
@@ -23,7 +23,7 @@ import java.io.IOException;
import java.io.Serializable;
import jogamp.graph.math.MathFloat;
-import org.apache.harmony.misc.HashCode;
+import jogamp.opengl.util.HashCode;
import com.jogamp.graph.geom.Vertex;
import com.jogamp.graph.geom.Vertex.Factory;
diff --git a/src/jogl/classes/org/apache/harmony/misc/HashCode.java b/src/jogl/classes/jogamp/opengl/util/HashCode.java
index e8ce8f620..f9a5d2fcb 100644
--- a/src/jogl/classes/org/apache/harmony/misc/HashCode.java
+++ b/src/jogl/classes/jogamp/opengl/util/HashCode.java
@@ -15,7 +15,7 @@
* limitations under the License.
*/
-package org.apache.harmony.misc;
+package jogamp.opengl.util;
/**
* This class is a convenience method to sequentially calculate hash code of the
diff --git a/src/jogl/classes/jogamp/graph/font/typecast/TypecastRenderer.java b/src/jogl/classes/jogamp/graph/font/typecast/TypecastRenderer.java
index 410f5b73a..9a81d78d3 100644
--- a/src/jogl/classes/jogamp/graph/font/typecast/TypecastRenderer.java
+++ b/src/jogl/classes/jogamp/graph/font/typecast/TypecastRenderer.java
@@ -27,16 +27,16 @@
*/
package jogamp.graph.font.typecast;
+import jogamp.graph.font.typecast.ot.OTGlyph;
+import jogamp.graph.font.typecast.ot.Point;
import jogamp.graph.geom.plane.AffineTransform;
import jogamp.graph.geom.plane.Path2D;
import com.jogamp.graph.font.Font;
-import net.java.dev.typecast.ot.Point;
-import net.java.dev.typecast.ot.OTGlyph;
/**
* Factory to build a {@link com.jogamp.graph.geom.Path2D Path2D} from
- * {@link net.java.dev.typecast.ot.OTGlyph Glyph}s.
+ * {@link jogamp.graph.font.typecast.ot.OTGlyph Glyph}s.
*/
public class TypecastRenderer {
@@ -84,7 +84,7 @@ public class TypecastRenderer {
/**
* Build a {@link com.jogamp.graph.geom.Path2D Path2D} from a
* {@link net.java.dev.typecast.ot.OTGlyph Glyph}. This glyph path can then
* be transformed and rendered.
*/
public static Path2D buildPath(OTGlyph glyph) {
@@ -84,7 +84,7 @@ public class TypecastRenderer {
/**
* Build a {@link com.jogamp.graph.geom.Path2D Path2D} from a
- * {@link net.java.dev.typecast.ot.OTGlyph Glyph}. This glyph path can then
+ * {@link jogamp.graph.font.typecast.ot.OTGlyph Glyph}. This glyph path can then
* be transformed and rendered.
*/